==> kvirc_2.1.2-11.tar.gz: kvirc-2.1.2/src/kvirc/kvi_query.h <==
#ifndef _KVI_QUERY_H_INCLUDED_
#define _KVI_QUERY_H_INCLUDED_

//
//   File : kvi_query.h (/usr/build/NEW_kvirc/kvirc/src/kvirc/kvi_query.h)
//   Last major modification : Thu Feb 11 1999 20:06:34 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_window.h"

class KviQuery : public KviWindow
{
	Q_OBJECT
public:		// Consruction & Destruction
	KviQuery(KviFrame *lpFrm,const char *name);
	~KviQuery();
protected:	// Protected methods
	virtual QPixmap * myIconPtr();
	virtual void resizeEvent(QResizeEvent *);
	virtual void applyOptions();
protected slots:
	void viewRightClicked(KviIrcView *);
	void viewPopupClicked(const KviStr &dataBuffer);
	void fileDroppedOnView(const char *fileName);
	void dndEnteredView();
};

#endif //_KVI_QUERY_H_INCLUDED_

==> kvirc_2.1.3.1.orig.tar.gz: kvirc-2.1.3.1/src/kvirc/kvi_query.h <==
#ifndef _KVI_QUERY_H_INCLUDED_
#define _KVI_QUERY_H_INCLUDED_

// =============================================================================
//
//      --- kvi_query.h ---
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// =============================================================================

#include "kvi_window.h"

class KviQuery : public KviWindow
{
	Q_OBJECT
public:
	KviQuery(KviFrame *lpFrm, const char *name);
	~KviQuery();
protected:
	virtual QPixmap *myIconPtr();

	virtual void resizeEvent(QResizeEvent *);
	virtual void applyOptions();
protected slots:
	void viewRightClicked(KviIrcView *);
	void viewPopupClicked(const KviStr &dataBuffer);
	void fileDroppedOnView(const char *fileName);
	void dndEnteredView();
};

#endif // _KVI_QUERY_H_INCLUDED_
